@@ -17,7 +17,10 @@ import pytest
 
 from pidcalib2 import pid_data
 
-THIS_DIR = os.path.dirname(os.path.abspath(__file__))
+
+@pytest.fixture
+def test_path():
+    return Path(os.path.dirname(os.path.abspath(__file__)))
 
 
 @pytest.mark.xrootd
@@ -80,28 +83,28 @@ def test_get_relevant_branch_names():
     }
 
 
-def test_dataframe_from_local_file():
+def test_dataframe_from_local_file(test_path):
     df = pid_data.dataframe_from_local_file(
-        str(Path(THIS_DIR, "test_data/cal_test_data.csv")), ["sWeight"]
+        str(test_path / "test_data/cal_test_data.csv"), ["sWeight"]
     )
     assert df.shape[0] == 99
     assert df["sWeight"][0] == pytest.approx(1.1081801082842266)
 
     df_pkl = pid_data.dataframe_from_local_file(
-        str(Path(THIS_DIR, "test_data/cal_test_data.pkl")), ["sw"]
+        str(test_path / "test_data/cal_test_data.pkl"), ["sw"]
     )
     assert df_pkl.shape[0] == 99
     assert df_pkl["sw"][0] == pytest.approx(1.1081801082842266)
 
     with pytest.raises(KeyError):
         pid_data.dataframe_from_local_file(
-            str(Path(THIS_DIR, "test_data/cal_test_data.csv")),
+            str(test_path / "test_data/cal_test_data.csv"),
             ["this key doesn't exist"],
         )
 
     with pytest.raises(Exception):
         pid_data.dataframe_from_local_file(
-            str(Path(THIS_DIR, "test_data/file.root")), ["sWeight"]
+            str(test_path / "test_data/file.root"), ["sWeight"]
         )
 
 
@@ -121,24 +124,32 @@ def test_get_reference_branch_name():
     )
 
 
-def test_get_calib_hists():
+def test_get_calib_hists(test_path):
     ref_pars = {"Bach": ["K", "DLLK > 4"]}
     bin_vars = {"P": "P", "ETA": "ETA", "nTracks": "nTracks"}
-    eff_histos = pid_data.get_calib_hists(
-        str(Path(THIS_DIR, "test_data")), "Turbo18", "up", ref_pars, bin_vars
+    eff_hists = pid_data.get_calib_hists(
+        str(test_path / "test_data"), "Turbo18", "up", ref_pars, bin_vars
     )
-    assert math.isnan(eff_histos["Bach"]["eff"].sum())  # type: ignore
-    assert eff_histos["Bach"]["eff"][4, 2, 1] == pytest.approx(0.9672206239134171)
-    assert eff_histos["Bach"]["passing"].sum() == pytest.approx(103762743.76872134)
-    assert eff_histos["Bach"]["total"].sum() == pytest.approx(114809531.81162772)
-    assert eff_histos["Bach"]["passing_sumw2"].sum() == pytest.approx(
-        130492602.73047148
+    assert math.isnan(eff_hists["Bach"]["eff"].sum().value)  # type: ignore
+    assert eff_hists["Bach"]["eff"][4, 2, 1].value == pytest.approx(  # type: ignore
+        0.9759721725381351
+    )
+    assert eff_hists["Bach"]["passing"].sum().value == pytest.approx(  # type: ignore
+        77882.51311058077
+    )
+    assert eff_hists["Bach"]["total"].sum().value == pytest.approx(  # type: ignore
+        86103.98549868543
+    )
+    assert eff_hists["Bach"]["passing"].sum().variance == pytest.approx(  # type: ignore
+        97895.25547125406
+    )
+    assert eff_hists["Bach"]["total"].sum().variance == pytest.approx(  # type: ignore
+        111911.08518551107
     )
-    assert eff_histos["Bach"]["total_sumw2"].sum() == pytest.approx(149177697.03949496)
 
     with pytest.raises(FileNotFoundError):
         pid_data.get_calib_hists(
-            str(Path(THIS_DIR, "test_data")),
+            str(test_path / "test_data"),
             "Turbo34",
             "up",
             ref_pars,
@@ -146,11 +157,11 @@ def test_get_calib_hists():
         )
 
 
-def test_get_calibration_sample():
+def test_get_calibration_sample(test_path):
     assert (
         len(
             pid_data.get_calibration_sample(
-                "Turbo18", "up", "Pi", str(Path(THIS_DIR, "../data/samples.json"))
+                "Turbo18", "up", "Pi", str(test_path / "../data/samples.json")
             )["files"]
         )
         == 428
@@ -161,7 +172,7 @@ def test_get_calibration_sample():
                 "Turbo18",
                 "up",
                 "Pi",
-                str(Path(THIS_DIR, "../data/samples.json")),
+                str(test_path / "../data/samples.json"),
                 3,
             )["files"]
         )
@@ -173,7 +184,7 @@ def test_get_calibration_sample():
                 "Electron18",
                 "down",
                 "e_B_Jpsi",
-                str(Path(THIS_DIR, "../data/samples.json")),
+                str(test_path / "../data/samples.json"),
             )["files"]
         )
         == 1
@@ -181,7 +192,7 @@ def test_get_calibration_sample():
     assert (
         len(
             pid_data.get_calibration_sample(
-                "20", "down", "K", str(Path(THIS_DIR, "../data/samples.json"))
+                "20", "down", "K", str(test_path / "../data/samples.json")
             )["files"]
         )
         == 72
@@ -189,5 +200,5 @@ def test_get_calibration_sample():
 
     with pytest.raises(KeyError):
         pid_data.get_calibration_sample(
-            "Turbo34", "up", "Pi", str(Path(THIS_DIR, "../data/samples.json"))
+            "Turbo34", "up", "Pi", str(test_path / "../data/samples.json")
         )
